"""A factory for building VCS Info instances."""

from .vcsinfo import Repository
from .exceptions import InvalidInputError
from .implementations.git import GitRepository


def build(path: str) -> Repository:
    """Build a VCS repository from a directory path.

    Raises:
        InvalidInputError: When the given path is not compatible with any known VCS implementation.
    """
    if GitRepository.is_compatible_path(path):
        return GitRepository(path)

    raise InvalidInputError('Path {path} is not compatible with any known VCS implementation.'.format(path=path))
